@@ -4,7 +4,7 @@ Pull requests are always welcomed"""
 from pywhatkit.ascii_art import image_to_ascii_art
 from pywhatkit.chr_to_handwriting import text_to_handwriting
 import pywhatkit.help
-from pywhatkit.main import prnt_sleeptm, check_window, sendwhatmsg, sendwhatmsg_to_group, info, playonyt, sendMail, search
+from pywhatkit.main import prnt_sleeptm, check_window, sendwhatmsg, sendwhatmsg_instantly, sendwhatmsg_to_group, info, playonyt, sendMail, search
 from pywhatkit.sc import shutdown, cancelShutdown
 from pywhatkit.wwd import watch_tutorial_in_Hindi, watch_tutorial_in_English, developer_contact
 from pywhatkit.history import showHistory
